# IO.Swagger.Api.ProjectsApi

All URIs are relative to *https://platform.its4land.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**AddTagToProject**](ProjectsApi.md#addtagtoproject) | **POST** /projects/{project_uid}/Tags | Adds a tag to the project
[**DelProjectByUID**](ProjectsApi.md#delprojectbyuid) | **DELETE** /projects/{project_uid} | Deletes a single e project by its UID
[**DetachProjectModel**](ProjectsApi.md#detachprojectmodel) | **DELETE** /projects/{project_uid}/Models/{model_uid} | Removes a model from a project.
[**DetachProjectSpatialSource**](ProjectsApi.md#detachprojectspatialsource) | **DELETE** /projects/{project_uid}/SpatialSources/{spatialsource_uid} | Removes a spatialsource from a project.
[**DetachProjectTag**](ProjectsApi.md#detachprojecttag) | **DELETE** /projects/{project_uid}/Tags/{tag} | Removes a tag from a project.
[**GetConnectedObjectsByProjectUID**](ProjectsApi.md#getconnectedobjectsbyprojectuid) | **GET** /projects/{project_uid}/connectedObjects | Returns an array of connect objects
[**GetModelsByProjectUID**](ProjectsApi.md#getmodelsbyprojectuid) | **GET** /projects/{project_uid}/Models | Returns the models of a project
[**GetProjectTagsByProjectUID**](ProjectsApi.md#getprojecttagsbyprojectuid) | **GET** /projects/{project_uid}/Tags | Returns the tags of a project.
[**GetProjects**](ProjectsApi.md#getprojects) | **GET** /projects | Get a GeoJSON structure containing a list of Projects.
[**GetProjectsByUID**](ProjectsApi.md#getprojectsbyuid) | **GET** /projects/{project_uid} | Getting single Projects by its UID
[**GetSpatialSourceByProjectUID**](ProjectsApi.md#getspatialsourcebyprojectuid) | **GET** /projects/{project_uid}/SpatialSources | Returns the SpatialSources of a Project.
[**NewModelUnderProject**](ProjectsApi.md#newmodelunderproject) | **POST** /projects/{project_uid}/Models | Create a new model
[**NewProject**](ProjectsApi.md#newproject) | **POST** /projects | Create a new project
[**NewSpatialSourceUnderProject**](ProjectsApi.md#newspatialsourceunderproject) | **POST** /projects/{project_uid}/SpatialSources | Create a new SpatialSource
[**UpdateProjects**](ProjectsApi.md#updateprojects) | **PATCH** /projects/{project_uid} | Update a project


<a name="addtagtoproject"></a>
# **AddTagToProject**
> ProjectsEndpointType AddTagToProject (string projectUid, TagsPostRequest newtag, string envelope = null, List<string> embed = null, string i4lProcessUid = null)

Adds a tag to the project

Creates a new tag and attach it to the project. If the tag already exist, the existing tag will be attached to the project.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class AddTagToProjectExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var newtag = new TagsPostRequest(); // TagsPostRequest | New Tag data
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 
            var i4lProcessUid = i4lProcessUid_example;  // string | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional) 

            try
            {
                // Adds a tag to the project
                ProjectsEndpointType result = apiInstance.AddTagToProject(projectUid, newtag, envelope, embed, i4lProcessUid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.AddTagToProject: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **newtag** | [**TagsPostRequest**](TagsPostRequest.md)| New Tag data | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **string**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="delprojectbyuid"></a>
# **DelProjectByUID**
> ProjectsEndpointType DelProjectByUID (string projectUid, string envelope = null, List<string> embed = null, string i4lProcessUid = null)

Deletes a single e project by its UID

A single project is deleted. This endpoint deletes the project itself and the connected to subordered data like SpatialSources, etc. The subordered data itself are not deleted

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DelProjectByUIDExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | UID of the project
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 
            var i4lProcessUid = i4lProcessUid_example;  // string | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional) 

            try
            {
                // Deletes a single e project by its UID
                ProjectsEndpointType result = apiInstance.DelProjectByUID(projectUid, envelope, embed, i4lProcessUid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.DelProjectByUID: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| UID of the project | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **string**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="detachprojectmodel"></a>
# **DetachProjectModel**
> ProjectsEndpointType DetachProjectModel (string projectUid, string modelUid, string envelope = null, string forceDelete = null)

Removes a model from a project.

Removes a model from a project. By default only the link between model and project is removed.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DetachProjectModelExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var modelUid = modelUid_example;  // string | Model UID
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var forceDelete = forceDelete_example;  // string | Deletes the model resource. ********* What's about subordinate resources? ********* (optional) 

            try
            {
                // Removes a model from a project.
                ProjectsEndpointType result = apiInstance.DetachProjectModel(projectUid, modelUid, envelope, forceDelete);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.DetachProjectModel: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **modelUid** | **string**| Model UID | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **forceDelete** | **string**| Deletes the model resource. ********* What&#39;s about subordinate resources? ********* | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="detachprojectspatialsource"></a>
# **DetachProjectSpatialSource**
> ProjectsEndpointType DetachProjectSpatialSource (string projectUid, string spatialsourceUid, string forceDelete = null)

Removes a spatialsource from a project.

Removes a spatial from a project. By default only the link between spatialsource and project is removed.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DetachProjectSpatialSourceExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var spatialsourceUid = spatialsourceUid_example;  // string | SpatialSource UID
            var forceDelete = forceDelete_example;  // string | Deletes the spatialsource resource. ********* What's about subordinate resources? ********* (optional) 

            try
            {
                // Removes a spatialsource from a project.
                ProjectsEndpointType result = apiInstance.DetachProjectSpatialSource(projectUid, spatialsourceUid, forceDelete);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.DetachProjectSpatialSource: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **spatialsourceUid** | **string**| SpatialSource UID | 
 **forceDelete** | **string**| Deletes the spatialsource resource. ********* What&#39;s about subordinate resources? ********* | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="detachprojecttag"></a>
# **DetachProjectTag**
> ProjectsEndpointType DetachProjectTag (string projectUid, string tag, string envelope = null, string forceDelete = null)

Removes a tag from a project.

Removes a tag from a project. By default only the link between tag and project is removed.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DetachProjectTagExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var tag = tag_example;  // string | tag value
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var forceDelete = forceDelete_example;  // string | Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. ********* (optional) 

            try
            {
                // Removes a tag from a project.
                ProjectsEndpointType result = apiInstance.DetachProjectTag(projectUid, tag, envelope, forceDelete);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.DetachProjectTag: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **tag** | **string**| tag value | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **forceDelete** | **string**| Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. ********* | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getconnectedobjectsbyprojectuid"></a>
# **GetConnectedObjectsByProjectUID**
> ConnectedObjectsEndpointType GetConnectedObjectsByProjectUID (string projectUid, string envelope = null, int? page = null, string sort = null, List<string> fields = null, List<string> embed = null)

Returns an array of connect objects

Returns an array of connect objects of a project. For each connected object the endpoint returns the type, name and uuid

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetConnectedObjectsByProjectUIDExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var page = 56;  // int? | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional) 
            var sort = sort_example;  // string | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional) 
            var fields = new List<string>(); // List<string> | Comma separated list of field names (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 

            try
            {
                // Returns an array of connect objects
                ConnectedObjectsEndpointType result = apiInstance.GetConnectedObjectsByProjectUID(projectUid, envelope, page, sort, fields, embed);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.GetConnectedObjectsByProjectUID: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **int?**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **string**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**List&lt;string&gt;**](string.md)| Comma separated list of field names | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**ConnectedObjectsEndpointType**](ConnectedObjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getmodelsbyprojectuid"></a>
# **GetModelsByProjectUID**
> List<ModelsEndpointType> GetModelsByProjectUID (string projectUid, string envelope = null, int? page = null, string sort = null, List<string> fields = null, List<string> embed = null)

Returns the models of a project

Returns the models of a project

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetModelsByProjectUIDExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var page = 56;  // int? | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional) 
            var sort = sort_example;  // string | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional) 
            var fields = new List<string>(); // List<string> | Comma separated list of field names (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 

            try
            {
                // Returns the models of a project
                List&lt;ModelsEndpointType&gt; result = apiInstance.GetModelsByProjectUID(projectUid, envelope, page, sort, fields, embed);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.GetModelsByProjectUID: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **int?**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **string**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**List&lt;string&gt;**](string.md)| Comma separated list of field names | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**List<ModelsEndpointType>**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getprojecttagsbyprojectuid"></a>
# **GetProjectTagsByProjectUID**
> TagsListResponse GetProjectTagsByProjectUID (string projectUid, string envelope = null)

Returns the tags of a project.

Is this method really necessary? Returns the tags of a project.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetProjectTagsByProjectUIDExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 

            try
            {
                // Returns the tags of a project.
                TagsListResponse result = apiInstance.GetProjectTagsByProjectUID(projectUid, envelope);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.GetProjectTagsByProjectUID: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 

### Return type

[**TagsListResponse**](TagsListResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getprojects"></a>
# **GetProjects**
> ProjectsEndpointType GetProjects (string envelope = null, List<string> uid = null, List<string> name = null, string aoi = null, List<string> tags = null, int? page = null, string sort = null, List<string> fields = null, List<string> embed = null)

Get a GeoJSON structure containing a list of Projects.

Get a GeoJSON structure containing a list of Projects. A single project is modeled as a GeoJSON feature.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetProjectsExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var uid = new List<string>(); // List<string> | Comma separated list of UID (optional) 
            var name = new List<string>(); // List<string> | Comma separated list of names (optional) 
            var aoi = aoi_example;  // string | Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1 (optional) 
            var tags = new List<string>(); // List<string> | Comma separated list of tags (optional) 
            var page = 56;  // int? | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional) 
            var sort = sort_example;  // string | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional) 
            var fields = new List<string>(); // List<string> | Comma separated list of field names (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 

            try
            {
                // Get a GeoJSON structure containing a list of Projects.
                ProjectsEndpointType result = apiInstance.GetProjects(envelope, uid, name, aoi, tags, page, sort, fields, embed);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.GetProjects: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **uid** | [**List&lt;string&gt;**](string.md)| Comma separated list of UID | [optional] 
 **name** | [**List&lt;string&gt;**](string.md)| Comma separated list of names | [optional] 
 **aoi** | **string**| Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1 | [optional] 
 **tags** | [**List&lt;string&gt;**](string.md)| Comma separated list of tags | [optional] 
 **page** | **int?**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **string**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**List&lt;string&gt;**](string.md)| Comma separated list of field names | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getprojectsbyuid"></a>
# **GetProjectsByUID**
> ProjectsEndpointType GetProjectsByUID (string projectUid, string envelope = null, List<string> embed = null)

Getting single Projects by its UID

Getting single Projects by its UID. The project is modeled as a feature in a GeoJSON structure.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetProjectsByUIDExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | UID of the project
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 

            try
            {
                // Getting single Projects by its UID
                ProjectsEndpointType result = apiInstance.GetProjectsByUID(projectUid, envelope, embed);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.GetProjectsByUID: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| UID of the project | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getspatialsourcebyprojectuid"></a>
# **GetSpatialSourceByProjectUID**
> List<SpatialSourcesEndpointType> GetSpatialSourceByProjectUID (string projectUid, string envelope = null, int? page = null, string sort = null, List<string> fields = null, List<string> embed = null)

Returns the SpatialSources of a Project.

Returns the SpatialSources of a Project.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetSpatialSourceByProjectUIDExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var page = 56;  // int? | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional) 
            var sort = sort_example;  // string | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional) 
            var fields = new List<string>(); // List<string> | Comma separated list of field names (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 

            try
            {
                // Returns the SpatialSources of a Project.
                List&lt;SpatialSourcesEndpointType&gt; result = apiInstance.GetSpatialSourceByProjectUID(projectUid, envelope, page, sort, fields, embed);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.GetSpatialSourceByProjectUID: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **int?**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **string**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**List&lt;string&gt;**](string.md)| Comma separated list of field names | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**List<SpatialSourcesEndpointType>**](SpatialSourcesEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="newmodelunderproject"></a>
# **NewModelUnderProject**
> ProjectsEndpointType NewModelUnderProject (string projectUid, ModelsPostRequest newmodel, string envelope = null, List<string> embed = null, string i4lProcessUid = null)

Create a new model

Create a new model.  To add a new Model , the content of Models  must be stored in advanced via the ContentItem endpoint

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class NewModelUnderProjectExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var newmodel = new ModelsPostRequest(); // ModelsPostRequest | New model data
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 
            var i4lProcessUid = i4lProcessUid_example;  // string | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional) 

            try
            {
                // Create a new model
                ProjectsEndpointType result = apiInstance.NewModelUnderProject(projectUid, newmodel, envelope, embed, i4lProcessUid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.NewModelUnderProject: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **newmodel** | [**ModelsPostRequest**](ModelsPostRequest.md)| New model data | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **string**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="newproject"></a>
# **NewProject**
> ProjectsEndpointType NewProject (ProjectsPostRequest newproject, string envelope = null, List<string> embed = null, string i4lProcessUid = null)

Create a new project

Create a new project. The new project is modeled as a feature in a GeoJSON structure. Currently only one project feature is allowed.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class NewProjectExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var newproject = new ProjectsPostRequest(); // ProjectsPostRequest | New project data
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 
            var i4lProcessUid = i4lProcessUid_example;  // string | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional) 

            try
            {
                // Create a new project
                ProjectsEndpointType result = apiInstance.NewProject(newproject, envelope, embed, i4lProcessUid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.NewProject: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newproject** | [**ProjectsPostRequest**](ProjectsPostRequest.md)| New project data | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **string**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="newspatialsourceunderproject"></a>
# **NewSpatialSourceUnderProject**
> ProjectsEndpointType NewSpatialSourceUnderProject (string projectUid, SpatialSourcesPostRequest newspatialsource, string envelope = null, List<string> embed = null, string i4lProcessUid = null)

Create a new SpatialSource

Create a new SpatialSource. To add a new SpatialSource , the content of SpatialSource  must be stored in advanced via the ContentItem endpoint

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class NewSpatialSourceUnderProjectExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID
            var newspatialsource = new SpatialSourcesPostRequest(); // SpatialSourcesPostRequest | New SpatialSource data
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 
            var i4lProcessUid = i4lProcessUid_example;  // string | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional) 

            try
            {
                // Create a new SpatialSource
                ProjectsEndpointType result = apiInstance.NewSpatialSourceUnderProject(projectUid, newspatialsource, envelope, embed, i4lProcessUid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.NewSpatialSourceUnderProject: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID | 
 **newspatialsource** | [**SpatialSourcesPostRequest**](SpatialSourcesPostRequest.md)| New SpatialSource data | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **string**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updateprojects"></a>
# **UpdateProjects**
> ProjectsEndpointType UpdateProjects (string projectUid, RFC6902PatchRequest patchproject, string envelope = null, List<string> embed = null, string i4lProcessUid = null)

Update a project

Updates some attributes of a project.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class UpdateProjectsExample
    {
        public void main()
        {
            var apiInstance = new ProjectsApi();
            var projectUid = projectUid_example;  // string | Project UID to be patched
            var patchproject = new RFC6902PatchRequest(); // RFC6902PatchRequest | Update data
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 
            var i4lProcessUid = i4lProcessUid_example;  // string | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional) 

            try
            {
                // Update a project
                ProjectsEndpointType result = apiInstance.UpdateProjects(projectUid, patchproject, envelope, embed, i4lProcessUid);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ProjectsApi.UpdateProjects: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **string**| Project UID to be patched | 
 **patchproject** | [**RFC6902PatchRequest**](RFC6902PatchRequest.md)| Update data | 
 **envelope** | **string**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**List&lt;string&gt;**](string.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **string**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

